@@ -37,10 +37,13 @@ def longReadMapping(strainName,longReads,reference,outputFolder,flag,longReadPla
     if p.stderr!="" or p.stdout !="":
         outputLog+="STDERR:\n\n"+p.stderr+"\n\nSTDOUT:\n\n"+p.stdout+"\n\n"
 
-    #Cleaning up
-    os.remove(samFile)
-    os.remove(passSamFile)
-    os.remove(sortedHeaderSamFile)
+    try:
+        #Cleaning up
+        os.remove(samFile)
+        os.remove(passSamFile)
+        os.remove(sortedHeaderSamFile)
+    except:
+        return outputLog,"Long reads not mapped to reference"
 
     return outputLog,"Long reads successfully mapped to reference"
 
@@ -64,7 +67,7 @@ def shortReadMapping(strainName,R1,R2,reference,outputFolder):
     outputLog+="COMMAND: "+" ".join(["samtools","view","-bT",reference,"-q","1",samFile,"-o",bamFile])+"\n\n"
     if p.stderr!="" or p.stdout !="":
         outputLog+="STDERR:\n\n"+p.stderr+"\n\nSTDOUT:\n\n"+p.stdout+"\n\n"
-    
+
     p=subprocess.run(["samtools", "sort", bamFile, "-o", sortedBamFile],stderr=subprocess.PIPE, stdout=subprocess.PIPE, universal_newlines=True)
     outputLog+="COMMAND: "+" ".join(["samtools", "sort", bamFile, "-o", sortedBamFile])+"\n\n"
     if p.stderr!="" or p.stdout !="":
@@ -125,7 +128,7 @@ def getShortReadPositions(hetVCFName,shortReadPosFileName):
                     pass
                 elif len(alt)<len(ref): #DEL
                     #for curPos in range(int(line[1])+1,int(line[1])+len(ref)):
-                    #	hetVCFPositions.add(chr+":"+str(curPos))
+                    #   hetVCFPositions.add(chr+":"+str(curPos))
                     pass
 
     #Writing the short read het positions to a file
@@ -206,8 +209,8 @@ def assignLongReadToSNPs(samPath,bedPath,referencePath,minQ,minMQ,minAln,outputP
             b=False
             while b==False:
                 if line[0]+"_"+str(i) not in readDict:
-                    readDict[line[0]+"_"+str(i)]=[]
-                    line[0]=line[0]+"_"+str(i)
+                    readDict[line[0]+"_VCSTTP_"+str(i)]=[] #Very Clean Solution To This Problem
+                    line[0]=line[0]+"_VCSTTP_"+str(i)
                     b=True
                 i+=1
 
@@ -231,11 +234,11 @@ def assignLongReadToSNPs(samPath,bedPath,referencePath,minQ,minMQ,minAln,outputP
         matchStart=False
         averageScore=0
         for Q in QLine:
-	    try:
+            try:
+                averageScore+=QScores[Q]
+            except:
+                QScores[Q]=ord(Q)-33
                 averageScore+=QScores[Q]
-	    except:
-		QScores[Q]=ord(Q)-33
-		averageScore+=QScores[Q]
         averageScore=int(averageScore/len(QLine))
         #
         #Okay so now we evaluate the cigar string and just slide down the SEQ and the reference simultaneously
@@ -360,7 +363,7 @@ def longReadValidation(longReadFilePath,minCov,minRatio,minTrioCov,validatedSNPA
     #vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv#
     ###########################################################################################
 
-    #Only keeping long reads that have unique combinations of SNPs 
+    #Only keeping long reads that have unique combinations of SNPs
     uniqueLongReadSets=set()
     uniqueLongReadIDs=set()
 
@@ -399,7 +402,19 @@ def longReadValidation(longReadFilePath,minCov,minRatio,minTrioCov,validatedSNPA
 
     return "Pre-processed long reads and generated context depth file"
 
+def getAvgFastQScore(fastQScoreStr):
+    fastQScoreStr=fastQScoreStr.strip()
+    totalScore=0
+    QScores={}
+    for baseQ in fastQScoreStr:
+        if baseQ not in QScores:
+            QScores[baseQ]=ord(baseQ)-33
+        totalScore+=QScores[baseQ]
+    avgScore=totalScore/len(fastQScoreStr)
+    return avgScore
+
 def generateLongReadFastQFiles(haplotigReadNameFilePath,longReadFastQFilePath,outputPath):
+    clusterStatsText=""
     haplotigReadDict={}
     haplotigReadNameFile=open(haplotigReadNameFilePath,"r")
     for line in haplotigReadNameFile:
@@ -411,46 +426,62 @@ def generateLongReadFastQFiles(haplotigReadNameFilePath,longReadFastQFilePath,ou
 
     haplotigReadNameFile.close()
 
-    gzipBool=True
-    
     longReadData={}
+    longReadMetaData={}
+
+    try:
+        longReadFastQFile=gzip.open(longReadFastQFilePath,"rt")
+        longReadFastQFile.readline()
+        longReadFastQFile.close()
+        longReadFastQFile=gzip.open(longReadFastQFilePath, "rt")
+    except gzip.BadGzipFile:
+        longReadFastQFile=open(longReadFastQFilePath,"r")
 
-    with gzip.open(longReadFastQFilePath, 'r') as fh:
-        try:
-            longReadFastQFile=gzip.open(longReadFastQFilePath,"rt")
-        except gzip.BadGzipFile:
-            longReadFastQFile=open(longReadFastQFilePath,"r")
     i=0
     for line in longReadFastQFile:
         line=line.strip("\n")
         if i%4==0:
-            readName=line
+            line=line.split()
+            readName=line[0]
             longReadData[readName]=[]
         else:
+            if i%4==3:
+                longReadMetaData[readName]=getAvgFastQScore(line)
             longReadData[readName].append(line)
         i+=1
     longReadFastQFile.close()
 
     for haplotigName, reads in haplotigReadDict.items():
         haplotigFastQText=""
+        totalScore=0
         for read in reads:
             read="@"+read
+            try:
+                totalScore+=longReadMetaData[read]
+            except:
+                read=read.split("_")[0]
+                totalScore+=longReadMetaData[read]
             readText=read+"\n"+"\n".join(longReadData[read])+"\n"
             haplotigFastQText+=readText
+        clusterStatsText+=haplotigName+"\t"+str(len(set(reads)))+"\t"+str(round(totalScore/len(reads)))+"\n"
         haplotigFile=gzip.open(outputPath+haplotigName+".fastq.gz",'wt')
         haplotigFile.write(haplotigFastQText)
         haplotigFile.close()
 
+    clusterStatsFile=open(outputPath+"clusterStats.tsv", 'w')
+    clusterStatsFile.write(clusterStatsText)
+    clusterStatsFile.close()
+
     return "Successfully generated phased FastQ files"
 
 def loadFile(filePath):
-	openFile=open(filePath,"r")
-	fileContents=[]
-	for line in openFile:
-		line=line.strip("\n").split("\t")
-		fileContents.append(line)
-	openFile.close()
-	return fileContents
+        openFile=open(filePath,"r")
+        fileContents=[]
+        for line in openFile:
+                line=line.strip("\n").split("\t")
+                fileContents.append(line)
+        openFile.close()
+        return fileContents
 
 def simplifyDataVis(dataVisPath,simpleOutPath,distance):
     fileContents=loadFile(dataVisPath)
@@ -492,9 +523,9 @@ def generateDataVis(dataVisPath,outPath):
     tbl = pd.read_csv(dataVisPath, sep="\t", header=None)
     tbl.columns = ["contigName", "startPos", "endPos", "chr", "yValue"]
 
-    #g=(ggplot(tbl,aes(y=tbl["yValue"],yend=tbl["yValue"],x=tbl["startPos"],xend=tbl["endPos"],color='factor(yValue)'))+geom_segment(size=1.5)+theme(legend_position="none")+theme(panel_grid_minor=element_blank())+facet_wrap("~chr",scales = "free")+theme(axis_title_y=element_blank(),axis_text_y=element_blank(),axis_ticks_major_y=element_blank())+xlab("Distance from start of genome (bp)")+theme(subplots_adjust={'hspace': 0.7}))
-    
-    g=(ggplot(tbl,aes(y=tbl["yValue"],yend=tbl["yValue"],x=tbl["startPos"],xend=tbl["endPos"],color='factor(yValue)'))+geom_segment(size=1.5)+theme(legend_position="none")+theme(panel_grid_minor=element_blank())+theme(axis_title_y=element_blank(),axis_text_y=element_blank(),axis_ticks_major_y=element_blank())+xlab("Distance from start of genome (bp)")+theme(subplots_adjust={'hspace': 0.7}))
+    g=(ggplot(tbl,aes(y=tbl["yValue"],yend=tbl["yValue"],x=tbl["startPos"],xend=tbl["endPos"],color='factor(yValue)'))+geom_segment(size=1.5)+theme(legend_position="none")+theme(panel_grid_minor=element_blank())+facet_wrap("~chr",scales = "free")+theme(axis_title_y=element_blank(),axis_text_y=element_blank(),axis_ticks_major_y=element_blank())+xlab("Distance from start of genome (bp)")+theme(subplots_adjust={'hspace': 0.7}))
+
+    #g=(ggplot(tbl,aes(y=tbl["yValue"],yend=tbl["yValue"],x=tbl["startPos"],xend=tbl["endPos"],color='factor(yValue)'))+geom_segment(size=1.5)+theme(legend_position="none")+theme(panel_grid_minor=element_blank())+theme(axis_title_y=element_blank(),axis_text_y=element_blank(),axis_ticks_major_y=element_blank())+xlab("Distance from start of genome (bp)")+theme(subplots_adjust={'hspace': 0.7}))
 
     ggsave(g,filename=outputSVG,width=18, height=10)
     ggsave(g,filename=outputPNG,width=18, height=10)
